==> haskell-hspec-wai-0.9.2-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai
version: 0.9.2
id: hspec-wai-0.9.2-LautgCGA52CHaJXCv7EZTb
key: hspec-wai-0.9.2-LautgCGA52CHaJXCv7EZTb
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2018 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Experimental Hspec support for testing WAI applications
description:
    Experimental Hspec support for testing WAI applications
category: Testing
abi: a0246d449e54051b9de92a8aef00be7a
exposed: True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck
hidden-modules: Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-wai-0.9.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-wai-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-wai-0.9.2
hs-libraries: HShspec-wai-0.9.2-LautgCGA52CHaJXCv7EZTb
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    hspec-core-2.7.0-9djGFHUQPDcITmQvcyNPMm
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    http-types-0.12.3-Ge4lCiHP3W4Hc9xNIKz9xs text-1.2.3.1
    transformers-0.5.6.2 wai-3.2.2-4c2pxdLfag64JAZMTaiyBj
    wai-extra-3.0.26-L7fmAc8O9CpB6cq7u614Fa
haddock-interfaces: /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-0.9.2-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai
version: 0.9.2
id: hspec-wai-0.9.2-3DMCMvZGrnT3MMpMksPKfu
key: hspec-wai-0.9.2-3DMCMvZGrnT3MMpMksPKfu
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2018 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Experimental Hspec support for testing WAI applications
description:
    Experimental Hspec support for testing WAI applications
category: Testing
abi: 2b10ea84562ddbb9da7479d1192fef6d
exposed: True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck
hidden-modules: Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-wai-0.9.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-wai-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-wai-0.9.2
hs-libraries: HShspec-wai-0.9.2-3DMCMvZGrnT3MMpMksPKfu
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    hspec-core-2.7.0-DBpMwnVZJPDBYljRVbjI2A
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    http-types-0.12.3-KTFxmt6v4566xpn9x45HFw text-1.2.3.1
    transformers-0.5.6.2 wai-3.2.2-GlQJpLVznLECwkQpTtQzT9
    wai-extra-3.0.26-4msHm6OBbMZH0eSBrqkizX
haddock-interfaces: /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
